@@ -1,21 +1,15 @@
 from collections import defaultdict
 from enum import Enum, unique
 from typing import Any, Dict, List, Optional, Union
-from uuid import uuid4
 
 import numpy as np
-import vaex
-from vaex.dataframe import DataFrame
 
-from dataquality.core._config import config
-from dataquality.exceptions import GalileoException
 from dataquality.loggers.logger_config.text_classification import (
     text_classification_logger_config,
 )
 from dataquality.loggers.model_logger.base_model_logger import BaseGalileoModelLogger
 from dataquality.schemas import __data_schema_version__
 from dataquality.schemas.split import Split
-from dataquality.utils.vaex import _save_hdf5_file
 
 
 @unique
@@ -132,26 +126,9 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
             if self.epoch > self.logger_config.last_epoch:
                 self.logger_config.last_epoch = self.epoch
 
-    def write_model_output(self, model_output: DataFrame) -> None:
-        location = (
-            f"{self.LOG_FILE_DIR}/{config.current_project_id}"
-            f"/{config.current_run_id}"
-        )
-
+    def write_model_output(self, model_output: Dict) -> None:
         self._set_num_labels(model_output)
-        epoch, split = model_output[["epoch", "split"]][0]
-        path = f"{location}/{split}/{epoch}"
-        object_name = f"{str(uuid4()).replace('-', '')[:12]}.hdf5"
-        _save_hdf5_file(path, object_name, model_output)
-
-    def _log(self) -> None:
-        """Threaded logger target implemented by child"""
-        try:
-            self.validate()
-        except AssertionError as e:
-            raise GalileoException(f"The provided GalileoModelConfig is invalid. {e}")
-        data = self._get_data_dict()
-        self.write_model_output(model_output=vaex.from_dict(data))
+        super().write_model_output(model_output)
 
     def _get_data_dict(self) -> Dict[str, Any]:
         data = defaultdict(list)
@@ -171,8 +148,8 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
                 data[k].append(record[k])
         return data
 
-    def _set_num_labels(self, df: DataFrame) -> None:
-        self.logger_config.observed_num_labels = len(df[:1]["prob"].values[0])
+    def _set_num_labels(self, data: Dict) -> None:
+        self.logger_config.observed_num_labels = len(data["prob"][0])
 
     def __setattr__(self, key: Any, value: Any) -> None:
         if key not in self.get_valid_attributes():
