@@ -1,12 +1,13 @@
 import os
 import shutil
+from typing import Any, Generator
 from uuid import uuid4
 
 import pytest
 from vaex.dataframe import DataFrame
 
 from dataquality import config
-from dataquality.clients import object_store
+from dataquality.clients import objectstore
 from dataquality.loggers import BaseGalileoLogger
 
 config.current_project_id = uuid4()
@@ -23,7 +24,7 @@ SUBDIRS = ["data", "emb", "prob"]
 
 
 @pytest.fixture(scope="function")
-def cleanup_after_use():
+def cleanup_after_use() -> Generator:
     try:
         if not os.path.isdir(TEST_PATH):
             for split in SPLITS:
@@ -34,7 +35,7 @@ def cleanup_after_use():
         shutil.rmtree(LOCATION)
 
 
-def patch_object_upload(df: DataFrame, object_name: str) -> None:
+def patch_object_upload(self: Any, df: DataFrame, object_name: str) -> None:
     """
     A patch for the object_store.create_project_run_object_from_df so we don't have to
     talk to minio for testing
@@ -50,4 +51,4 @@ def patch_object_upload(df: DataFrame, object_name: str) -> None:
 
 
 # Patch the upload so we don't write to S3/minio
-object_store.create_project_run_object_from_df = patch_object_upload
+objectstore.ObjectStore.create_project_run_object_from_df = patch_object_upload
